import React, { useState } from 'react'
import dimensions from '../dimensions'
import Pagination from './Pagination'

// props: measurements, paginate, itemsPerPage, totalHits
export default function MeasurementsList(props) {
  // console.log("measurementsList props", props)
  let dimensionOpts = {}
  for (const d of dimensions.keys) {
    dimensionOpts[d] = true
  }

  const [index, setIndex] = useState(0)
  const [options, setOptions] = useState(dimensionOpts)

  function goBack() {
    if (index > 0) {
      setIndex(index - 1)
      try {
        props.paginate(index - 1);
      } 
      catch (e) { console.log(e) }
    }
  }

  function goForward() {
    if (((index + 1) * props.itemsPerPage) < props.totalHits) {
      setIndex(index + 1)
      try {
        props.paginate(index + 1);
      } 
      catch (e) { console.log(e) }
    }
  }

  function viewClicked(id) {
    console.log('selecting model', id)
    props.selectItem(props.selectedItem === id ? null : id)
  }

  const pagination = 
    <Pagination index={index} 
                itemsPerPage={props.itemsPerPage} 
                totalHits={props.totalHits}
                goBack={goBack} goForward={goForward} />

  const headerCells = 
    dimensions.displayNames.map(d => <th className="pr-5 text-xs text-center text-gray-600 font-normal" key={d}>{d}</th>)

  function row(measurement) {
    return dimensions.keys.map(d => {
      return (
        <td className="pr-5 w-40 text-center" 
            key={measurement.MeasurementID + d}>{measurement[d] ? parseFloat(measurement[d]).toFixed(2) : '--'}
        </td>
      )
    })
  }
  const rows =
    props.measurements.map(m => {
      return (
        <tr className={m.MeasurementID === props.selectedItem ? 'bg-teal-300' : 'zebra'} key={m.MeasurementID}>
          <td className="py-2 px-5">
            <button className="border-b-2 text-center text-sm font-bold text-gray-600 uppercase"
                    onClick={() => viewClicked(m.MeasurementID)}>
              {props.selectedItem === m.MeasurementID ? 'Hide' : 'View'}          
            </button>
          </td>
          {row(m)}
        </tr>
      )
    })
  const table =
    <table className="table-fixed overflow-x-auto bg-white">
      <thead>
        <tr className="bg-gray-200">
          <th></th>
          {headerCells}
        </tr>
      </thead>
      <tbody>
        {rows}
      </tbody>
    </table>

  return (
    <div className={props.className}>
      <div className="h-full flex flex-col bg-gray-300">
        {pagination}
        <div className="flex-1 overflow-x-auto bg-white">
          {table}
        </div>
        {pagination}
      </div>
      {/* <MeasurementResultOptions setSelected={this.setSelected} selectedMeasurements={this.getSelected} /> */}
    </div>
  )
}