import React, { useState, useEffect, useCallback } from 'react'
import {
  useLocation
} from "react-router-dom"

import MeasurementsList from './MeasurementsList'
import SearchOptionsPane from './SearchOptionsPane'
import ModelViewer from './ModelViewer'

import dimensions from '../dimensions'
import db from '../db'

export default function SearchResults(props) {

  const [searchParams, setSearchParams] = useState({})
  const [totalHits, setTotalHits] = useState(0)
  const [itemsPerPage, setItemsPerPage] = useState(0)
  const [pageRequest, setPageRequest] = useState(null)
  const [measurements, setMeasurements] = useState([])
  const [selectedModel, setSelectedModel] = useState(null)

  const location = useLocation()

  useEffect(() => {
    const urlSearchParams = new URLSearchParams(location.search)
    let parsedSearchParams = {}
    for (const [i, sn] of dimensions.shortNames.entries()) {
      const val = urlSearchParams.get(sn)
      if (val) {
        const [min, max] = val.split(',')
        parsedSearchParams[dimensions.keys[i]] = {
          min: parseFloat(min),
          max: parseFloat(max)
        }
      }
    }
    setSearchParams(parsedSearchParams)
    let parsedItemsPerPage = urlSearchParams.has('itemsPerPage') ? parseInt(urlSearchParams.get('itemsPerPage')) : 10
    setItemsPerPage(parsedItemsPerPage)
    db.query(
      parsedSearchParams,
      parsedItemsPerPage,
      (hits, pageCount, pageRequest) => {
        setTotalHits(hits)
        const paginate = (index) => {
          pageRequest(index).then(measurements => {
            console.log('setting measurements to:', measurements)
            setMeasurements(measurements)
          })
        }
        // request first page
        paginate()
        setPageRequest(() => paginate)
      },
      (err) => {

      }
    )
  }, [location.search])

  let modelViewer = null
  if (selectedModel) {
    modelViewer = <ModelViewer  className="my-5 w-1/2 bg-gray-300 border border-gray-400 rounded-lg overflow-hidden" 
                                modelId={selectedModel} />
  }
  else {
    modelViewer = <div />
  }
  return (
    <div className="flex items-stretch ">
      <SearchOptionsPane  className="m-5 w-72 flex-none p-5 border rounded-lg" 
                          searchParams={searchParams} />
      {modelViewer}
      <MeasurementsList   className="m-5 overflow-hidden border rounded-lg" 
                          measurements={measurements} 
                          paginate={pageRequest}
                          itemsPerPage={itemsPerPage}
                          totalHits={totalHits} 
                          selectItem={(id) => setSelectedModel(id)}
                          selectedItem={selectedModel} />
    </div>
  )
}