import React, {useState, useEffect} from 'react'
import { useHistory } from 'react-router-dom'
import AttributeRange from './AttributeRange'
import dimensions from '../dimensions'

// props: itemsPerPage, searchParams, submitSearch
export default function SearchOptionsPane(props) {

  // console.log('rendering SearchOptionsPage with', props)
  const [itemsPerPage, setItemsPerPage] = useState('10')
  const [dimensionRanges, setDimensionRanges] = useState(props.searchParams || {})

  useEffect(() => {
    setDimensionRanges(props.searchParams || {})
    console.log('SearchOptionsPane props:', props.searchParams)
  }, [props.searchParams])

  const history = useHistory()

  function rangeUpdated(dimension, range) {
    console.log(dimension, 'updated, range:', range)
    let currentRange = dimensionRanges[dimension]
    if (range === currentRange || (range && currentRange && range.min === currentRange.min && range.max === currentRange.max)) {
      console.log('ignoring dimension update')
      return
    }
    // dimensionRanges[dimension] = range
    setDimensionRanges(ranges => {
      ranges = {...ranges}
      ranges[dimension] = range
      if (!range) { delete ranges[dimension] }
      
      console.log('setting new ranges to', ranges)
      return ranges
    })
  }

  function itemsPerPageSelected(event) {
    setItemsPerPage(event.target.value)
  }

  function formSubmitted(event) {
    event.preventDefault()
    const searchString = 
      Object.entries(dimensionRanges)
            .map(([d, r]) => `${dimensions.shortName(d)}=${r.min},${r.max}`)
            .join('&')
    let path =`/search?itemsPerPage=${itemsPerPage}` + (searchString ? '&' + searchString : '')
    history.push(path)
    // props.submitSearch(dimensionRanges, parseInt(itemsPerPage, 10))
  }

  return (
    <div className={props.className}>
      <div className="flex flex-col">
        <div>
          {dimensions.keys.map((d, i) => (
            <AttributeRange key={d} 
                            label={dimensions.displayNames[i]} 
                            range={dimensionRanges[d]}
                            extents={{min: 0, max: 200}}
                            updateRange={(range) => rangeUpdated(d, range)}/>)
          )}
        </div>
        <form className="mt-5"
              onSubmit={formSubmitted}>
          <div className="flex justify-between items-baseline">
            <span>Measurements per page:</span>
            <select className="ml-4 bg-gray-200 rounded border"
                    value={itemsPerPage} 
                    onChange={itemsPerPageSelected}>
              <option value='5'>5</option>
              <option value='10'>10</option>
              <option value='25'>25</option>
              <option value='50'>50</option>
            </select>
          </div>
          <div>
            <input  type="submit" className="mt-2 px-2 py-1 w-full bg-teal-600 text-white rounded shadow" value="Search" />
          </div>
        </form>
      </div>
    </div>
  )
}